@@ -154,6 +154,14 @@ from plaid.model.credit_employment_get_request import CreditEmploymentGetRequest
 from plaid.model.credit_employment_get_response import CreditEmploymentGetResponse
 from plaid.model.credit_employment_verification import CreditEmploymentVerification
 from plaid.model.credit_filter import CreditFilter
+from plaid.model.credit_pay_stub import CreditPayStub
+from plaid.model.credit_pay_stub_address import CreditPayStubAddress
+from plaid.model.credit_pay_stub_deductions import CreditPayStubDeductions
+from plaid.model.credit_pay_stub_earnings import CreditPayStubEarnings
+from plaid.model.credit_pay_stub_employee import CreditPayStubEmployee
+from plaid.model.credit_pay_stub_employer import CreditPayStubEmployer
+from plaid.model.credit_pay_stub_net_pay import CreditPayStubNetPay
+from plaid.model.credit_pay_stub_verification import CreditPayStubVerification
 from plaid.model.credit_payroll_income_get_request import CreditPayrollIncomeGetRequest
 from plaid.model.credit_payroll_income_get_response import CreditPayrollIncomeGetResponse
 from plaid.model.credit_payroll_income_precheck_request import CreditPayrollIncomePrecheckRequest
@@ -320,6 +328,7 @@ from plaid.model.liability_override import LiabilityOverride
 from plaid.model.link_token_account_filters import LinkTokenAccountFilters
 from plaid.model.link_token_create_credit_filter import LinkTokenCreateCreditFilter
 from plaid.model.link_token_create_depository_filter import LinkTokenCreateDepositoryFilter
+from plaid.model.link_token_create_institution_data import LinkTokenCreateInstitutionData
 from plaid.model.link_token_create_investment_filter import LinkTokenCreateInvestmentFilter
 from plaid.model.link_token_create_loan_filter import LinkTokenCreateLoanFilter
 from plaid.model.link_token_create_request import LinkTokenCreateRequest
@@ -367,21 +376,13 @@ from plaid.model.pay import Pay
 from plaid.model.pay_frequency import PayFrequency
 from plaid.model.pay_frequency_value import PayFrequencyValue
 from plaid.model.pay_period_details import PayPeriodDetails
-from plaid.model.pay_stub import PayStub
-from plaid.model.pay_stub_address import PayStubAddress
-from plaid.model.pay_stub_deductions import PayStubDeductions
 from plaid.model.pay_stub_deductions_breakdown import PayStubDeductionsBreakdown
 from plaid.model.pay_stub_deductions_total import PayStubDeductionsTotal
 from plaid.model.pay_stub_distribution_breakdown import PayStubDistributionBreakdown
-from plaid.model.pay_stub_earnings import PayStubEarnings
 from plaid.model.pay_stub_earnings_breakdown import PayStubEarningsBreakdown
 from plaid.model.pay_stub_earnings_total import PayStubEarningsTotal
-from plaid.model.pay_stub_employee import PayStubEmployee
-from plaid.model.pay_stub_employer import PayStubEmployer
-from plaid.model.pay_stub_net_pay import PayStubNetPay
 from plaid.model.pay_stub_pay_period_details import PayStubPayPeriodDetails
 from plaid.model.pay_stub_taxpayer_id import PayStubTaxpayerID
-from plaid.model.pay_stub_verification import PayStubVerification
 from plaid.model.pay_stub_verification_attribute import PayStubVerificationAttribute
 from plaid.model.payment_amount import PaymentAmount
 from plaid.model.payment_amount_currency import PaymentAmountCurrency
@@ -438,6 +439,7 @@ from plaid.model.payment_scheme import PaymentScheme
 from plaid.model.payment_status_update_webhook import PaymentStatusUpdateWebhook
 from plaid.model.payroll_income_object import PayrollIncomeObject
 from plaid.model.payroll_item import PayrollItem
+from plaid.model.payroll_item_status import PayrollItemStatus
 from plaid.model.paystub import Paystub
 from plaid.model.paystub_address import PaystubAddress
 from plaid.model.paystub_deduction import PaystubDeduction
@@ -559,6 +561,7 @@ from plaid.model.transactions_get_request import TransactionsGetRequest
 from plaid.model.transactions_get_request_options import TransactionsGetRequestOptions
 from plaid.model.transactions_get_response import TransactionsGetResponse
 from plaid.model.transactions_recurring_get_request import TransactionsRecurringGetRequest
+from plaid.model.transactions_recurring_get_request_options import TransactionsRecurringGetRequestOptions
 from plaid.model.transactions_recurring_get_response import TransactionsRecurringGetResponse
 from plaid.model.transactions_refresh_request import TransactionsRefreshRequest
 from plaid.model.transactions_refresh_response import TransactionsRefreshResponse
@@ -598,6 +601,7 @@ from plaid.model.transfer_event_list_transfer_type import TransferEventListTrans
 from plaid.model.transfer_event_sync_request import TransferEventSyncRequest
 from plaid.model.transfer_event_sync_response import TransferEventSyncResponse
 from plaid.model.transfer_event_type import TransferEventType
+from plaid.model.transfer_events_update_webhook import TransferEventsUpdateWebhook
 from plaid.model.transfer_failure import TransferFailure
 from plaid.model.transfer_get_request import TransferGetRequest
 from plaid.model.transfer_get_response import TransferGetResponse
